.. This file is auto-generated by setup.py for PyPI using pandoc, so this
.. file should not be edited.  Edits should go into the files from which
.. this file is constructed.
..
.. This file contains the long_description argument to setup.py's setup().
.. It should be checked into source control and be part of the source
.. distribution so that setup() can be passed the long_description argument
.. by end-users even without pandoc (e.g. non-maintainers, etc).


Pizza
=====

.. figure:: http://cjerdonek.github.com/groome/images/python-pizza.jpeg
   :alt: python eating pizza

|Build Status|

`Pizza <https://github.com/cjerdonek/groome-python-expected>`__ is a
sample demonstration project of a `Python <http://www.python.org>`__
command-line script.

Pizza is the project you get when you render the
`Groome <http://cjerdonek.github.com/groome>`__ project template
`groome-python <https://github.com/cjerdonek/groome-python>`__ with its
sample configuration file. For testing purposes, this project also
serves as the "expected" value of that template. See the
`groome-python <https://github.com/cjerdonek/groome-python>`__ project
page for more information about this project.

A minimal sample usage looks like--

::

    $ python runpizza.py hello crazy world
    3

The project page and source code is on
`GitHub <https://github.com/cjerdonek/groome-python-expected>`__, and
releases can be found on `PyPI <http://pypi.python.org/pypi/Pizza>`__
(the Python Package Index).

Feedback is welcome. You can file bug reports and feature requests on
the `project
tracker <https://github.com/cjerdonek/groome-python-expected/issues>`__.

[This project and ``groome-python`` are still being worked on and are
not yet usable.]

Requirements
------------

Pizza supports the following Python versions:

-  Python 2.7
-  Python 3.2
-  Python 3.3
-  `PyPy <http://pypy.org/>`__

Pizza has no third-party dependencies.

Installing for Python 3 requires that
`Distribute <http://packages.python.org/distribute/>`__ be installed and
that `pip <http://www.pip-installer.org/>`__ use Distribute.

Install It
----------

::

    $ pip install pizza

Test it
-------

::

    TODO [template]:

Try it
------

::

    TODO [template]:

Hack it
-------

TODO [template]: merge this section with the "For Contributors" section.
We may want to move this information to developing.md.

This section describes how to modify and contribute to Pizza. In
particular, it shows you the way around and how to interact with Pizza
from a source checkout.

To run the main ``pizza`` script from source:

::

    $ python runpizza.py tomatoes garlic
    input: tomatoes, garlic

This script is essentially a development convenience for running:

::

    $ python -m pizza.scripts.pizza ...

which is in turn equivalent to the command above that To get help and
see all options:

::

    $ python runpizza.py --help

To run project tests (which are already stubbed out):

::

    $ python runpizza.py --run-tests

For Contributors
----------------

For guidance on working with the Pizza code base, consult the
``developing.md`` file in the ``docs`` folder of a source distribution.

For Maintainers
---------------

For instructions on releasing Pizza and on how to use ``setup.py``,
consult the ``releasing.md`` file in the ``docs`` folder of a source
distribution.

Author
------

Pizza is authored by `Chris Jerdonek <https://github.com/cjerdonek>`__.

Copyright
---------

Copyright (C) 2013 Chris Jerdonek. All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

-  Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.
-  Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.
-  The names of the copyright holders may not be used to endorse or
   promote products derived from this software without specific prior
   written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

History
=======

0.1.0 (TBD)
-----------

-  Initial release.

.. |Build Status| image:: https://travis-ci.org/cjerdonek/groome-python-expected.png
   :target: https://travis-ci.org/cjerdonek/groome-python-expected
